package be.iminds.ilabt.jfed.restapi.dao;

import be.iminds.ilabt.jfed.fedmon.webapi.service.json.Frequency;
import be.iminds.ilabt.jfed.fedmon.webapi.service.json.FrequencyBuilder;
import be.iminds.ilabt.jfed.restapi.json.Experiment;
import be.iminds.ilabt.jfed.restapi.json.ExperimentBuilder;
import be.iminds.ilabt.jfed.util.GeniUrn;
import org.skife.jdbi.v2.StatementContext;
import org.skife.jdbi.v2.tweak.ResultSetMapper;

import java.net.MalformedURLException;
import java.net.URL;
import java.sql.ResultSet;
import java.sql.SQLException;

public class ExperimentMapper implements ResultSetMapper<Experiment>
{
    public Experiment map(int index, ResultSet r, StatementContext ctx) throws SQLException
    {
        ExperimentBuilder res = new ExperimentBuilder();
        res.setId(r.getLong("id"));
//        res.setName(r.getString("name"));
        res.setCreated(r.getTimestamp("created"));
        res.setExpire(r.getTimestamp("expire"));
        res.setRequestRspec(r.getString("request_rspec"));
        res.setManifestRspec(r.getString("manifest_rspec"));
        res.setSpeaksForCredential(r.getString("speaks_for_credential"));
        try {
            res.setSpeakingFor(r.getString("speaking_for"));
        } catch (GeniUrn.GeniUrnParseException e) {
            throw new SQLException("Malformed speaking_for URN stored in DB", e);
        }
        res.setProject(r.getString("project"));
        res.setSliceName(r.getString("slice_name"));
        try {
            String sliceUrnString = r.getString("slice_urn");
            res.setSliceUrn(sliceUrnString == null ? null : new GeniUrn(sliceUrnString));
        } catch (GeniUrn.GeniUrnParseException e) {
            throw new SQLException("Malformed slice URN stored in DB", e);
        }
        try {
            String amUrl = r.getString("am_url");
            res.setAm(amUrl == null ? null : new URL(amUrl));
        } catch (MalformedURLException e) {
            throw new SQLException("Malformed URL stored in DB", e);
        }
//        res.setXXXX(r.getString("shared_with")); //TODO
        try {
            String ownerString = r.getString("owner");
            res.setOwner(ownerString == null ? null : new GeniUrn(ownerString));
        } catch (GeniUrn.GeniUrnParseException e) {
            throw new SQLException("Malformed owner URN stored in DB", e);
        }
        String statusString = r.getString("status");
        res.setStatus(statusString == null ? null : Experiment.Status.valueOf(statusString));
//        res.setXXXX(r.getString("status_details")); //TODO
        return res.create();
    }
}
